Installation
============

yalchemy can be installed with::

    pip3 install yalchemy

To improve performance, it is recommended to install `LibYAML <https://github.com/yaml/libyaml>`_ to leverage
the native C implementation of the `PyYaml <https://github.com/yaml/pyyaml>`_ parser.
